@@ -36,7 +36,7 @@ class Nowfm(object):
         method = 'user.getrecenttracks'
         url = self.url_template + '&method={0}&limit=1&user={1}'.format(
             method, user)
-        jobj = json.loads(urllib.urlopen(url).read())
+        jobj = json.loads(unicode(urllib.urlopen(url).read(), 'utf-8'))
         tracks = jobj['recenttracks']['track']
         if type(tracks) is not list:
             return None
@@ -111,7 +111,7 @@ class Nowfm(object):
         else:
             url += '&track={0}&artist={1}'.format(
                 track['name'], track['artist']['#text'])
-        jobj = json.loads(urllib.urlopen(url).read())
+        jobj = json.loads(unicode(urllib.urlopen(url).read(), 'utf-8'))
         return jobj['track']
 
     def _thread_get_track_info(self, track, ret):
